Learn R Programming

signal (version 0.7-2)

an: Complex unit phasor of the given angle in degrees.

Description

Complex unit phasor of the given angle in degrees.

Usage

an(degrees)

Arguments

degrees
Angle in degrees.

Value

  • A complex value or array of exp(1i*degrees*pi/180).

Details

This is a utility function to make it easier to specify phasor values as a magnitude times an angle in degrees.

Examples

Run this code
120*an(30) + 125*an(-160)

Run the code above in your browser using DataLab