## S3 method for class 'default':
impz(filt, a = 1, n = NULL, Fs = 1, \ldots)
## S3 method for class 'Arma':
impz(filt, \ldots)
## S3 method for class 'Ma':
impz(filt, \ldots)
## S3 method for class 'impz':
plot(x, xlab = "Time, msec", ylab = "", type = "l",
main = "Impulse response", \ldots)
## S3 method for class 'impz':
print(x, xlab = "Time, msec", ylab = "", type = "l",
main = "Impulse response", \ldots)filt
specifies an arbitrary model or filter operation.impz, arguments are passed to
the default method. For plot.impz, additional arguments are
passed through to plot.plot, uses lines to connect the pointsimpz, a list of class impz with items:impz are printed, the impulse response will be
plotted. As with
lattice plots, automatic printing does not work inside loops and
function calls, so explicit calls to print or plot are
needed there.filter, freqz, zplanebt <- butter(5, 0.3)
impz(bt)
impz(ellip(5, 0.5, 30, 0.3))Run the code above in your browser using DataLab