Learn R Programming

signal (version 0.7-2)

roots: Roots of a polynomial

Description

Roots of a polynomial

Usage

roots(x, method = c("polyroot", "eigen"))

Arguments

x
Polynomial coefficients with coefficients given in order from highest to lowest polynomial power. This is the Matlab/Octave convention; it is opposite of the convention used by polyroot.
method
Either polyroot (default) which uses polyroot for its computations internally (and is typically more accurate) or eigen which uses eigenvalues of the companion matri

Value

  • A complex array with the roots of the polynomial.

References

Octave Forge http://octave.sf.net

See Also

polyroot, polyval, poly, conv

Examples

Run this code
roots(1:3)
polyroot(3:1) # should be the same
poly(roots(1:3))

roots(1:3, method="eigen") # using eigenvalues

Run the code above in your browser using DataLab