Learn R Programming

signal (version 0.7-2)

wav: Example wav file

Description

Example wav file audio waveshape from Octave.

Usage

data(wav)

Arguments

format

The format is: List of 3 $ sound: num [1, 1:17380] -0.000275 -0.00061 -0.000397 -0.000793 -0.000305 ... $ rate : int 22050 $ bits : int 16 - attr(*, "class")= chr "Sample"

source

Octave

Details

Sound samples are in Element sound while rate is the sampling rate (in Hz) and bits the resolution of the underlying Wave file.

Examples

Run this code
data(wav)
str(wav)

Run the code above in your browser using DataLab