Returns the filter coefficients of the n-point Dolph-Chebyshev window
with a given attenuation.
Usage
chebwin(n, at)
Arguments
n
length of the filter; number of coefficients to generate.
at
dB of attenuation in the stop-band of the corresponding
Fourier transform.
Value
An array of length n with the filter coefficients.
encoding
latin1
Details
The window is described in frequency domain by the expression:
$$W(k) = \frac{Cheb(n-1, \beta * cos(pi * k/n))}{Cheb(n-1, \beta)}$$
with
$$\beta = cosh(1/(n-1) * acosh(10^{at/20}))$$
and $Cheb(m,x)$ denoting the $m$-th order Chebyshev polynomial calculated
at the point $x$.
Note that the denominator in $W(k)$ above is not computed, and after
the inverse Fourier transform the window is scaled by making its
maximum value unitary.
References
Peter Lynch, The Dolph-Chebyshev Window: A Simple Optimal Filter,
Monthly Weather Review, Vol. 125, pp. 655-660, April 1997.
http://www.maths.tcd.ie/~plynch/Publications/Dolph.pdf
C. Dolph, A current distribution for broadside arrays which
optimizes the relationship between beam width and side-lobe level,
Proc. IEEE, 34, pp. 335-348.
Octave Forge http://octave.sf.net