Polynomial coefficients with coefficients given in order from highest to lowest
polynomial power. This is the Matlab/Octave convention; it is
opposite of the convention used by polyroot.
method
Either polyroot (default) which uses polyroot for its computations internally
(and is typically more accurate) or eigen which uses eigenvalues of the companion matri